@@ -60,7 +60,6 @@ from pikepdf.models import (
     PageLocation,
     PdfImage,
     PdfInlineImage,
-    PdfMatrix,
     Permissions,
     UnsupportedImageTypeError,
     make_page_destination,
@@ -130,7 +129,6 @@ __all__ = [
     'PageLocation',
     'PdfImage',
     'PdfInlineImage',
-    'PdfMatrix',
     'Permissions',
     'UnsupportedImageTypeError',
     'make_page_destination',
