@@ -14,7 +14,6 @@ from pikepdf.models._content_stream import (
 )
 from pikepdf.models.encryption import Encryption, EncryptionInfo, Permissions
 from pikepdf.models.image import PdfImage, PdfInlineImage, UnsupportedImageTypeError
-from pikepdf.models.matrix import PdfMatrix
 from pikepdf.models.metadata import PdfMetadata
 from pikepdf.models.outlines import (
     Outline,
@@ -36,7 +35,6 @@ __all__ = [
     'PdfImage',
     'PdfInlineImage',
     'UnsupportedImageTypeError',
-    'PdfMatrix',
     'PdfMetadata',
     'Outline',
     'OutlineItem',
