@@ -5,7 +5,6 @@
 
 from __future__ import annotations
 
-import sys
 from abc import ABC, abstractmethod
 from copy import copy
 from decimal import Decimal
@@ -33,16 +32,10 @@ from pikepdf.objects import (
 
 T = TypeVar('T')
 
-if sys.version_info >= (3, 9):
-    RGBDecodeArray = tuple[float, float, float, float, float, float]
-    GrayDecodeArray = tuple[float, float]
-    CMYKDecodeArray = tuple[float, float, float, float, float, float, float, float]
-    DecodeArray = Union[RGBDecodeArray, GrayDecodeArray, CMYKDecodeArray]
-else:
-    RGBDecodeArray = Any
-    GrayDecodeArray = Any
-    CMYKDecodeArray = Any
-    DecodeArray = Any
+RGBDecodeArray = tuple[float, float, float, float, float, float]
+GrayDecodeArray = tuple[float, float]
+CMYKDecodeArray = tuple[float, float, float, float, float, float, float, float]
+DecodeArray = Union[RGBDecodeArray, GrayDecodeArray, CMYKDecodeArray]
 
 
 class UnsupportedImageTypeError(Exception):
@@ -202,6 +195,8 @@ class PdfImageBase(ABC):
                 if isinstance(subspace, list) and subspace[0] in (
                     '/ICCBased',
                     '/DeviceN',
+                    '/CalGray',
+                    '/CalRGB',
                 ):
                     return subspace[0]
             if self._colorspaces[0] == '/DeviceN':
@@ -329,16 +324,16 @@ class PdfImageBase(ABC):
             _idx, base, _hival, lookup = self._colorspaces
         except ValueError as e:
             raise ValueError('Not sure how to interpret this palette') from e
-        if self.icc or self.is_device_n or self.is_separation:
+        if self.icc or self.is_device_n or self.is_separation or isinstance(base, list):
             base = str(base[0])
         else:
             base = str(base)
         lookup = bytes(lookup)
         if base not in self.MAIN_COLORSPACES and base not in self.PRINT_COLORSPACES:
             raise NotImplementedError(f"not sure how to interpret this palette: {base}")
-        if base == '/DeviceRGB':
+        if base in ('/DeviceRGB', '/CalRGB'):
             base = 'RGB'
-        elif base == '/DeviceGray':
+        elif base in ('/DeviceGray', '/CalGray'):
             base = 'L'
         elif base == '/DeviceCMYK':
             base = 'CMYK'
@@ -348,6 +343,8 @@ class PdfImageBase(ABC):
             base = 'Separation'
         elif base == '/ICCBased':
             base = self._approx_mode_from_icc()
+        else:
+            raise NotImplementedError(f"not sure how to interpret this palette: {base}")
         return PaletteData(base, lookup)
 
     @abstractmethod
@@ -755,7 +752,6 @@ class PdfImage(PdfImageBase):
 
         expected_defaults = [
             ("/EncodedByteAlign", False),
-            ("/EndOfLine", False),
         ]
         for name, val in expected_defaults:
             if self.decode_parms[0].get(name, val) != val:
@@ -1043,10 +1039,10 @@ class PdfInlineImage(PdfImageBase):
 
     def read_bytes(self):
         """Return decompressed image bytes."""
-        # QPDF does not have an API to return this directly, so convert it.
+        # qpdf does not have an API to return this directly, so convert it.
         return self._convert_to_pdfimage().read_bytes()
 
     def get_stream_buffer(self):
         """Return decompressed stream buffer."""
-        # QPDF does not have an API to return this directly, so convert it.
+        # qpdf does not have an API to return this directly, so convert it.
         return self._convert_to_pdfimage().get_stream_buffer()
